@@ -2,21 +2,23 @@ define(
 //begin v1.x content
 {
 	"HKD_displayName": "dólar hongkonés",
-	"CHF_displayName": "franco suizo",
-	"JPY_symbol": "JPY",
-	"CAD_displayName": "dólar canadiense",
-	"HKD_symbol": "HKD",
 	"CNY_displayName": "yuan",
-	"USD_symbol": "$",
-	"AUD_displayName": "dólar australiano",
 	"JPY_displayName": "yen",
-	"CAD_symbol": "CA$",
+	"JPY_symbol": "JPY",
 	"USD_displayName": "dólar estadounidense",
-	"CNY_symbol": "CNY",
+	"CAD_symbol": "CA$",
 	"GBP_displayName": "libra británica",
+	"CHF_displayName": "franco suizo",
+	"CNY_symbol": "CNY",
+	"EUR_displayName": "euro",
 	"GBP_symbol": "GBP",
-	"AUD_symbol": "AUD",
-	"EUR_displayName": "euro"
+	"CAD_displayName": "dólar canadiense",
+	"USD_symbol": "$",
+	"EUR_symbol": "€",
+	"AUD_displayName": "dólar australiano",
+	"CHF_symbol": "CHF",
+	"HKD_symbol": "HKD",
+	"AUD_symbol": "AUD"
 }
 //end v1.x content
 );
\ No newline at end of file
