@@ -2,21 +2,23 @@ define(
 //begin v1.x content
 {
 	"HKD_displayName": "dollaro di Hong Kong",
-	"CHF_displayName": "franco svizzero",
-	"JPY_symbol": "JPY",
-	"CAD_displayName": "dollaro canadese",
-	"HKD_symbol": "HKD",
 	"CNY_displayName": "renminbi cinese",
-	"USD_symbol": "US$",
-	"AUD_displayName": "dollaro australiano",
 	"JPY_displayName": "yen giapponese",
-	"CAD_symbol": "CA$",
+	"JPY_symbol": "JPY",
 	"USD_displayName": "dollaro statunitense",
+	"CAD_symbol": "CA$",
+	"GBP_displayName": "sterlina britannica",
+	"CHF_displayName": "franco svizzero",
 	"CNY_symbol": "CN¥",
-	"GBP_displayName": "sterlina inglese",
+	"EUR_displayName": "euro",
 	"GBP_symbol": "£",
-	"AUD_symbol": "A$",
-	"EUR_displayName": "euro"
+	"CAD_displayName": "dollaro canadese",
+	"USD_symbol": "US$",
+	"EUR_symbol": "€",
+	"AUD_displayName": "dollaro australiano",
+	"CHF_symbol": "CHF",
+	"HKD_symbol": "HKD",
+	"AUD_symbol": "A$"
 }
 //end v1.x content
 );
\ No newline at end of file
