@@ -2,21 +2,23 @@ define(
 //begin v1.x content
 {
 	"HKD_displayName": "Хонгконшки долар",
-	"CHF_displayName": "Швајцарски Франк",
-	"JPY_symbol": "JPY",
-	"CAD_displayName": "Канадски долар",
-	"HKD_symbol": "HKD",
 	"CNY_displayName": "Кинески јуан",
-	"USD_symbol": "US$",
-	"AUD_displayName": "Австралиски долар",
 	"JPY_displayName": "Јапонски јен",
-	"CAD_symbol": "CA$",
+	"JPY_symbol": "JPY",
 	"USD_displayName": "Американски долар",
-	"CNY_symbol": "CNY",
+	"CAD_symbol": "CA$",
 	"GBP_displayName": "Британска Фунта",
+	"CHF_displayName": "Швајцарски Франк",
+	"CNY_symbol": "CNY",
+	"EUR_displayName": "Евро",
 	"GBP_symbol": "GBP",
-	"AUD_symbol": "AUD",
-	"EUR_displayName": "Евро"
+	"CAD_displayName": "Канадски долар",
+	"USD_symbol": "US$",
+	"EUR_symbol": "€",
+	"AUD_displayName": "Австралиски долар",
+	"CHF_symbol": "CHF",
+	"HKD_symbol": "HKD",
+	"AUD_symbol": "AUD"
 }
 //end v1.x content
 );
\ No newline at end of file
