@@ -2,22 +2,23 @@ define(
 //begin v1.x content
 {
 	"HKD_displayName": "Гонконгский доллар",
-	"CHF_displayName": "Швейцарский франк",
-	"JPY_symbol": "¥",
-	"CAD_displayName": "Канадский доллар",
-	"HKD_symbol": "HK$",
 	"CNY_displayName": "Китайский юань",
-	"USD_symbol": "$",
-	"AUD_displayName": "Австралийский доллар",
 	"JPY_displayName": "Японская иена",
-	"CAD_symbol": "CA$",
+	"JPY_symbol": "¥",
 	"USD_displayName": "Доллар США",
-	"EUR_symbol": "€",
+	"CAD_symbol": "CA$",
+	"GBP_displayName": "Британский фунт стерлингов",
+	"CHF_displayName": "Швейцарский франк",
 	"CNY_symbol": "CN¥",
-	"GBP_displayName": "Английский фунт",
+	"EUR_displayName": "Евро",
 	"GBP_symbol": "£",
-	"AUD_symbol": "A$",
-	"EUR_displayName": "Евро"
+	"CAD_displayName": "Канадский доллар",
+	"USD_symbol": "$",
+	"EUR_symbol": "€",
+	"AUD_displayName": "Австралийский доллар",
+	"CHF_symbol": "CHF",
+	"HKD_symbol": "HK$",
+	"AUD_symbol": "A$"
 }
 //end v1.x content
 );
\ No newline at end of file
