@@ -2,22 +2,23 @@ define(
 //begin v1.x content
 {
 	"HKD_displayName": "港元",
-	"CHF_displayName": "瑞士法郎",
-	"JPY_symbol": "JP¥",
-	"CAD_displayName": "加拿大元",
-	"HKD_symbol": "HK$",
 	"CNY_displayName": "人民币",
-	"USD_symbol": "US$",
-	"AUD_displayName": "澳大利亚元",
 	"JPY_displayName": "日元",
-	"CAD_symbol": "CA$",
+	"JPY_symbol": "JP¥",
 	"USD_displayName": "美元",
-	"EUR_symbol": "€",
-	"CNY_symbol": "￥",
+	"CAD_symbol": "CA$",
 	"GBP_displayName": "英镑",
+	"CHF_displayName": "瑞士法郎",
+	"CNY_symbol": "￥",
+	"EUR_displayName": "欧元",
 	"GBP_symbol": "£",
-	"AUD_symbol": "AU$",
-	"EUR_displayName": "欧元"
+	"CAD_displayName": "加拿大元",
+	"USD_symbol": "US$",
+	"EUR_symbol": "€",
+	"AUD_displayName": "澳大利亚元",
+	"CHF_symbol": "CHF",
+	"HKD_symbol": "HK$",
+	"AUD_symbol": "AU$"
 }
 //end v1.x content
 );
\ No newline at end of file
